@@ -19,11 +19,11 @@ Audit::DBI - Audit data changes in your code and store searchable log records in
 
 =head1 VERSION
 
-Version 1.4.1
+Version 1.4.2
 
 =cut
 
-our $VERSION = '1.4.1';
+our $VERSION = '1.4.2';
 
 
 =head1 SYNOPSIS
@@ -942,7 +942,7 @@ sub insert_event
 		my @values = ();
 		foreach my $field ( keys %$data )
 		{
-			push( @fields, $dbh->quote( $field) );
+			push( @fields, $dbh->quote_identifier( $field) );
 			push( @values, $data->{ $field } );
 		}
 		my $insert = $dbh->do(
